@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.97 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: amenu.c,v 1.104 2010/06/03 12:45:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -37,6 +37,9 @@
 
 /***************************************************************/
 
+/* ذưʤɤǥ˥塼ꥻåȤ뤫? */
+#define	FLG_RESET_MENU	0
+
 #define	STR_TTL_AUTO_MARK_SPLIT_NAME	" - "
 #define	STR_TTL_AUTO_MARK_SPLIT_CODE	"\n"
 
@@ -77,6 +80,7 @@ static auto_mark_t	dflt_auto_mark_fight = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_prio = {
@@ -86,6 +90,7 @@ static auto_mark_t	dflt_auto_mark_fight_prio = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_throw = {
@@ -95,6 +100,7 @@ static auto_mark_t	dflt_auto_mark_throw = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_NULL,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_throw_prio = {
@@ -104,6 +110,7 @@ static auto_mark_t	dflt_auto_mark_throw_prio = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_far = {
@@ -113,6 +120,7 @@ static auto_mark_t	dflt_auto_mark_fight_far = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_NULL,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_far_prio = {
@@ -122,6 +130,7 @@ static auto_mark_t	dflt_auto_mark_fight_far_prio = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_all = {
@@ -131,6 +140,7 @@ static auto_mark_t	dflt_auto_mark_fight_all = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_all_prio = {
@@ -140,6 +150,7 @@ static auto_mark_t	dflt_auto_mark_fight_all_prio = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_item_all = {
@@ -149,6 +160,7 @@ static auto_mark_t	dflt_auto_mark_item_all = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_item_own = {
@@ -158,6 +170,7 @@ static auto_mark_t	dflt_auto_mark_item_own = {
 	AUTO_MARK_COND_OWN,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY | FLG_AUTO_MARK_EDIT_CONT,
+	DFLT_AUTO_MARK_NULL,
 };
 
 static auto_mark_t	dflt_auto_mark_clear = {
@@ -167,6 +180,7 @@ static auto_mark_t	dflt_auto_mark_clear = {
 	AUTO_MARK_COND_DISPERSE,
 	"",
 	FLG_AUTO_MARK_EDIT_PRIORITY,
+	DFLT_AUTO_MARK_NULL,
 };
 
 check_memory_def( check_memory_amenu_c_dflt_auto_mark_fight )
@@ -281,8 +295,10 @@ void	reset_static_auto_menu( void )
 {
 	long	i;
 
+#if	FLG_RESET_MENU
 	g_sel_mbr = NULL;
 	auto_mark_cur_n = 0;
+#endif
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ )
 		clip_board_large[i] = dflt_auto_mark_fight;
@@ -354,8 +370,11 @@ void	init_auto_mark_all_mbr( void )
 
 void	init_auto_mark_mbr( long ls_mbr_n )
 {
+	mbr_t	**ls_mbr;
 	long	j;
 
+	ls_mbr = get_ls_mbr();
+
 	/*  */
 
 	for( j = 0; j < AUTO_MARK_MAX_N; j++ ){
@@ -370,157 +389,97 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 
 	/* Ʈ(ɲ) */
 
-	switch( ls_mbr_n ){
-	default:
-	case 0:
-	case 1:
-	case 3:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight;
-		break;
-	case 2:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_throw;
-		break;
-	case 4:
-	case 5:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
-		break;
-	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
 			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT;
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* Ʈ() */
 
-	switch( ls_mbr_n ){
-	default:
-	case 0:
-	case 1:
-	case 3:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_prio;
-		break;
-	case 2:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_throw_prio;
-		break;
-	case 4:
-	case 5:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
-		break;
-	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT_PRIO;
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* ܶƮ(ɲ) */
 
-	switch( ls_mbr_n ){
-	default:
-	case 0:
-	case 1:
-	case 2:
-	case 3:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight;
-		break;
-	case 4:
-	case 5:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far;
-		break;
-	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
 			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT_NO_THROW;
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* ܶƮ() */
 
-	switch( ls_mbr_n ){
-	default:
-	case 0:
-	case 1:
-	case 2:
-	case 3:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_prio;
-		break;
-	case 4:
-	case 5:
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_far_prio;
-		break;
-	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
 			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO;
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* (ɲ) */
 
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT_ALL;
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* () */
 
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
-	j++;
-
-	/*  */
-
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_RETREAT,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
-	j++;
-
-	/*  */
-
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_FIGHT_ALL_PRIO;
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* ƤΥƥ */
 
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_ITEM_ALL;
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
 	/* äƤ륢ƥ */
 
-	if( j < AUTO_MARK_MAX_N ){
-		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_own;
-		str_nz_cpy( msg_ttl_auto_mark[j],
-				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
-				MSG_TTL_AUTO_MARK_MAX_BYTE );
-		ls_flg_ena_auto_mark[j] = TRUE;
-	}
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_ITEM_OWN;
+	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
+
+	/*  */
+
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_RETREAT,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_flg_ena_auto_mark[j] = TRUE;
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_RETREAT;
+	j++;
+
+	/*  */
+
+	str_nz_cpy( msg_ttl_auto_mark[j],
+			MSG_NAME_DFLT_AUTO_MARK_CLEAR,
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
+	ls_auto_mark[ls_mbr_n][j].dflt = DFLT_AUTO_MARK_CLEAR;
+	ls_flg_ena_auto_mark[j] = TRUE;
+	j++;
+
+	/* ǥեȤ */
+
+	set_dflt_auto_mark_mbr( ls_mbr_n );
 }
 
 /***************************************************************
@@ -538,6 +497,144 @@ void	init_auto_mark_new_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 }
 
+/***************************************************************
+* СΥǥեȤμưޡ
+* long ls_mbr_n : СΥꥹֹ
+***************************************************************/
+
+void	set_dflt_auto_mark_mbr( long ls_mbr_n )
+{
+	auto_mark_t	*p;
+	long	n;
+
+	for( n = DFLT_AUTO_MARK_NULL + 1; n < DFLT_AUTO_MARK_MAX_N; n++ ){
+		p = srch_dflt_auto_mark( ls_mbr_n, (dflt_auto_mark_t)n );
+		set_dflt_auto_mark( ls_mbr_n, p );
+	}
+}
+
+/***************************************************************
+* ǥեȤμưޡ
+* long ls_mbr_n : СΥꥹֹ
+* auto_mark_t *p : ưޡ
+***************************************************************/
+
+void	set_dflt_auto_mark( long ls_mbr_n, auto_mark_t *p )
+{
+	auto_mark_t	*forward, *halfback, *back;
+	dflt_auto_mark_t	dflt;
+	mbr_t	**ls_mbr;
+
+	if( p == NULL )
+		return;
+
+	forward = &dflt_auto_mark_clear;
+	halfback = &dflt_auto_mark_clear;
+	back = &dflt_auto_mark_clear;
+
+	switch( p->dflt ){
+	case DFLT_AUTO_MARK_NULL:
+	case DFLT_AUTO_MARK_MAX_N:
+		return;
+	case DFLT_AUTO_MARK_FIGHT:
+		/* Ʈ(ɲ) */
+		forward = &dflt_auto_mark_fight;
+		halfback = &dflt_auto_mark_throw;
+		back = &dflt_auto_mark_fight_far;
+		break;
+	case DFLT_AUTO_MARK_FIGHT_PRIO:
+		/* Ʈ() */
+		forward = &dflt_auto_mark_fight_prio;
+		halfback = &dflt_auto_mark_throw_prio;
+		back = &dflt_auto_mark_fight_far_prio;
+		break;
+	case DFLT_AUTO_MARK_FIGHT_NO_THROW:
+		/* ܶƮ(ɲ) */
+		forward = &dflt_auto_mark_fight;
+		halfback = &dflt_auto_mark_fight;
+		back = &dflt_auto_mark_fight_far;
+		break;
+	case DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO:
+		/* ܶƮ() */
+		forward = &dflt_auto_mark_fight_prio;
+		halfback = &dflt_auto_mark_fight_prio;
+		back = &dflt_auto_mark_fight_far_prio;
+		break;
+	case DFLT_AUTO_MARK_FIGHT_ALL:
+		/* (ɲ) */
+		forward = &dflt_auto_mark_fight_all;
+		halfback = &dflt_auto_mark_fight_all;
+		back = &dflt_auto_mark_fight_all;
+		break;
+	case DFLT_AUTO_MARK_FIGHT_ALL_PRIO:
+		/* () */
+		forward = &dflt_auto_mark_fight_all_prio;
+		halfback = &dflt_auto_mark_fight_all_prio;
+		back = &dflt_auto_mark_fight_all_prio;
+		break;
+	case DFLT_AUTO_MARK_ITEM_ALL:
+		/* ƤΥƥ */
+		forward = &dflt_auto_mark_item_all;
+		halfback = &dflt_auto_mark_item_all;
+		back = &dflt_auto_mark_item_all;
+		break;
+	case DFLT_AUTO_MARK_ITEM_OWN:
+		/* äƤ륢ƥ */
+		forward = &dflt_auto_mark_item_own;
+		halfback = &dflt_auto_mark_item_own;
+		back = &dflt_auto_mark_item_own;
+		break;
+	case DFLT_AUTO_MARK_RETREAT:
+		/*  */
+		forward = &dflt_auto_mark_clear;
+		halfback = &dflt_auto_mark_clear;
+		back = &dflt_auto_mark_clear;
+		break;
+	case DFLT_AUTO_MARK_CLEAR:
+		/*  */
+		forward = &dflt_auto_mark_clear;
+		halfback = &dflt_auto_mark_clear;
+		back = &dflt_auto_mark_clear;
+		break;
+	}
+
+	ls_mbr = get_ls_mbr();
+
+	dflt = p->dflt;
+	switch( ls_mbr[ls_mbr_n]->position_kind ){
+	case POSITION_KIND_NULL:
+	case POSITION_KIND_MAX_N:
+		break;
+	case POSITION_KIND_FORWARD:
+		*p = *forward;
+		break;
+	case POSITION_KIND_HALFBACK:
+		*p = *halfback;
+		break;
+	case POSITION_KIND_BACK:
+		*p = *back;
+		break;
+	}
+	p->dflt = dflt;
+}
+
+/***************************************************************
+* ǥեȤμưޡ򸡺
+* long ls_mbr_n : СΥꥹֹ
+* dflt_auto_mark_t n : ǥեȤμưޡμ
+***************************************************************/
+
+auto_mark_t	*srch_dflt_auto_mark( long ls_mbr_n, dflt_auto_mark_t n )
+{
+	long	j;
+
+	for( j = 0; j < AUTO_MARK_MAX_N; j++ )
+		if( ls_auto_mark[ls_mbr_n][j].dflt == n )
+			return &(ls_auto_mark[ls_mbr_n][j]);
+
+	return NULL;
+}
+
 /***************************************************************
 * ΥСʥå
 * long ls_mbr_n : СΥꥹֹ
@@ -666,6 +763,34 @@ void	ver_up_auto_mark_1_1_3( void )
 		cv_msg_ttl_auto_mark( msg_ttl_auto_mark[j] );
 }
 
+/***************************************************************
+* ΥСʥå
+***************************************************************/
+
+void	ver_up_auto_mark_1_2_35( void )
+{
+	auto_mark_t	*p;
+	long	n, m;
+	long	ls_mbr_n;
+
+	/* ǥեȤκɲ */
+
+	for( n = DFLT_AUTO_MARK_NULL + 1; n < DFLT_AUTO_MARK_MAX_N; n++ ){
+		m = AUTO_MARK_MAX_N - (DFLT_AUTO_MARK_MAX_N - n);
+		for( ls_mbr_n = 0; ls_mbr_n < LS_MBR_MAX_N; ls_mbr_n++ ){
+			p = &(ls_auto_mark[ls_mbr_n][m]);
+			set_dflt_auto_mark( ls_mbr_n, p );
+		}
+	}
+
+	/* Ƭ¤ؤ */
+
+	for( n = DFLT_AUTO_MARK_MAX_N - 1; n > DFLT_AUTO_MARK_NULL; n-- ){
+		m = AUTO_MARK_MAX_N - 1;
+		arrange_auto_mark( m, -1 );
+	}
+}
+
 /***************************************************************
 * ȥζڤʸ " - "  "\n" Ѵ
 * char *ttl : ȥ
@@ -756,17 +881,6 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p[k].flg = FLG_NULL;
 	k++;
 
-	str_nz_cpy( p[k].path, "/auto mark/title", MENU_PATH_MAX_LEN );
-	str_nz_cpy( p[k].kind, "<Title>", MENU_KIND_MAX_LEN );
-	p[k].accel_key = '\0';
-	p[k].short_key[0] = '\0';
-	str_nz_cpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
-			MENU_MSG_MAX_BYTE );
-	p[k].call_back = NULL;
-	p[k].arg = NULL;
-	p[k].flg = FLG_NULL;
-	k++;
-
 	left_max_len = 1;
 	for( i = 0; i < AUTO_MARK_MAX_N; i++ ){
 		long	len;
@@ -797,22 +911,45 @@ void	set_menu_auto_mark( menu_t **dflt )
 			key = 'A';
 		}
 
+		if( (i % AUTO_MARK_N_PER_PAGE) == 0 ){
+			str_nz_cpy( p[k].path, "/auto mark/title",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( p[k].kind, "<Title>",
+					MENU_KIND_MAX_LEN );
+			p[k].accel_key = '\0';
+			p[k].short_key[0] = '\0';
+			str_nz_cpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
+					MENU_MSG_MAX_BYTE );
+			p[k].call_back = NULL;
+			p[k].arg = NULL;
+			p[k].flg = FLG_NULL;
+			k++;
+		}
+
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
 		kk = k;
 
 		if( ls_flg_ena_auto_mark[i] ){
+			int	len;
+
+			len = get_pading_len( get_msg_ttl_auto_mark_info( i ),
+					left_max_len );
 			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
-					(int)left_max_len,
+					len,
 					get_msg_ttl_auto_mark_info( i ),
 					STR_TTL_AUTO_MARK_SPLIT_NAME,
 					get_msg_ttl_auto_mark_hint( i ) );
 		} else {
+			int	len;
+
+			len = get_pading_len( MSG_MENU_AUTO_MARK_NULL,
+					left_max_len );
 			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
-					(int)left_max_len,
+					len,
 					MSG_MENU_AUTO_MARK_NULL,
 					STR_TTL_AUTO_MARK_SPLIT_NAME,
 					MSG_MENU_AUTO_MARK_NULL );
@@ -1590,6 +1727,11 @@ char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt )
 
 	auto_mark_cur_n = (long)((*pp)->arg);
 
+	if( ls_auto_mark[0][auto_mark_cur_n].dflt != DFLT_AUTO_MARK_NULL ){
+		print_msg( FLG_MSG_ERR, MSG_MENU_AUTO_MARK_CAN_NOT_EDIT );
+		return STR_MENU_CANCEL;
+	}
+
 	ls_flg_ena_auto_mark[auto_mark_cur_n] = TRUE;
 	set_menu_auto_mark( dflt );
 
@@ -2545,8 +2687,14 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 
 	n = (long)((*pp)->arg);
 
+	if( ls_auto_mark[0][n].dflt != DFLT_AUTO_MARK_NULL ){
+		print_msg( FLG_MSG_ERR, MSG_MENU_AUTO_MARK_CAN_NOT_EDIT );
+		return STR_MENU_CANCEL;
+	}
+
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
 		ls_auto_mark[i][n] = clip_board_large[i];
+		ls_auto_mark[i][n].dflt = DFLT_AUTO_MARK_NULL;
 
 		for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
 			auto_mark_appoint_item[i][n][k]
@@ -2601,12 +2749,23 @@ char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 {
 	long	k;
+	long	ls_mbr_n;
 
-	ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n]
+	ls_mbr_n = g_sel_mbr->ls_mbr_n;
+
+	if( ls_auto_mark[ls_mbr_n][auto_mark_cur_n].dflt
+			!= DFLT_AUTO_MARK_NULL ){
+		print_msg( FLG_MSG_ERR, MSG_MENU_AUTO_MARK_CAN_NOT_EDIT );
+		return STR_MENU_CANCEL;
+	}
+
+	ls_auto_mark[ls_mbr_n][auto_mark_cur_n]
 			= clip_board_small;
+	ls_auto_mark[ls_mbr_n][auto_mark_cur_n].dflt
+			= DFLT_AUTO_MARK_NULL;
 
 	for( k = 0; k < AUTO_MARK_APPOINT_ITEM_MAX_N; k++ ){
-		auto_mark_appoint_item[g_sel_mbr->ls_mbr_n]
+		auto_mark_appoint_item[ls_mbr_n]
 				[auto_mark_cur_n][k]
 				= clip_board_small_item[k];
 	}
@@ -2673,6 +2832,13 @@ char	*cb_menu_auto_mark_remove( menu_t **pp, menu_t **dflt )
 	ask_t	ask;
 	long	n;
 
+	n = (long)((*pp)->arg);
+
+	if( ls_auto_mark[0][n].dflt != DFLT_AUTO_MARK_NULL ){
+		print_msg( FLG_MSG_ERR, MSG_MENU_AUTO_MARK_CAN_NOT_EDIT );
+		return STR_MENU_CANCEL;
+	}
+
 	ask = exec_menu_ask( MSG_TTL_MENU_AUTO_MARK_ASK_REMOVE,
 			ASK_NO, TRUE );
 	if( ask == ASK_ERR )
@@ -2680,7 +2846,6 @@ char	*cb_menu_auto_mark_remove( menu_t **pp, menu_t **dflt )
 	if( ask != ASK_YES )
 		return STR_MENU_CANCEL;
 
-	n = (long)((*pp)->arg);
 	ls_flg_ena_auto_mark[n] = FALSE;
 
 	set_menu_auto_mark( dflt );
