@@ -136,17 +136,19 @@ void	exp_chr(
 	bool_t flg_print_exp,
 	bool_t flg_print_lev
 );
-void	exp_mbr(
+bool_t	exp_mbr(
 	mbr_t *mbr,
 	long exp,
 	bool_t flg_set_max,
-	bool_t flg_print_lev
+	bool_t flg_print_lev,
+	bool_t flg_draw_lev
 );
-void	exp_mbr_skill(
+bool_t	exp_mbr_skill(
 	mbr_t *mbr,
 	long exp,
 	bool_t flg_set_max,
-	bool_t flg_print_lev
+	bool_t flg_print_lev,
+	bool_t flg_draw_lev
 );
 long	exp_mbr_skill_1(
 	mbr_t *mbr,
@@ -154,19 +156,23 @@ long	exp_mbr_skill_1(
 	skill_kind_t kind,
 	bool_t flg_set_max
 );
-void	exp_mnstr(
+bool_t	exp_mnstr(
 	mnstr_t *mnstr,
 	long exp,
 	bool_t flg_set_max,
-	bool_t flg_print_lev
+	bool_t flg_print_lev,
+	bool_t flg_draw_lev
+);
+bool_t	chk_lev_up(
+	chr_t *chr, bool_t flg_set_max,
+	bool_t flg_print, bool_t flg_draw
 );
-void	chk_lev_up( chr_t *chr, bool_t flg_set_max, bool_t flg_draw );
 bool_t	set_lev_up(
 	chr_t *chr,
 	abl_kind_t abl,
 	long add,
 	bool_t flg_set_max,
-	bool_t flg_draw );
+	bool_t flg_print );
 void	set_modifier( chr_t *chr );
 void	set_modifier_fx_data_equip( chr_t *chr );
 void	set_modifier_fx_data_fx( chr_t *chr );
