@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.168 2009/09/13 17:08:17 bowkenken Exp $
+* $Id: fight.c,v 1.171 2010/05/29 14:37:00 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -365,45 +365,83 @@ bool_t	set_attack_mnstr_bash(
 
 /***************************************************************
 * ֹ
-* chr_t *chr : ¦饯
-* chr_t *chr2 : ɸ¦饯
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
 * attack_t *dflt_attack : ǥեȤιǡ
 * return : ?
 ***************************************************************/
 
-bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
+bool_t	fight_throw( chr_t *o_p, chr_t *d_p, attack_t *dflt_attack )
 {
-	item_t	*eq;
 	attack_t	attack;
 	long	d;
 
-	if( chr1 == NULL )
+	if( o_p == NULL )
 		return FALSE;
 
-	if( is_mbr( chr1 ) ){
-		eq = get_mbr_item_asgn_equip( chr1 );
-		if( eq == NULL )
-			return FALSE;
+	/* check stick */
+	if( chk_fight_zap( o_p ) )
+		return fight_zap( o_p );
 
-		/* check stick */
-
-		if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
-			if( !zap_stick( chr1, &(eq[EQUIP_KIND_BOW]) ) )
-				clr_chr_trgt_act( chr1, FALSE );
-			return TRUE;
-		}
-	}
-
-	d = get_trgt_range( chr1 );
+	d = get_trgt_range( o_p );
 
 	if( dflt_attack == NULL ){
-		if( !set_attack_chr_throw( chr1, &attack, d, FALSE ) )
+		if( !set_attack_chr_throw( o_p, &attack, d, FALSE ) )
 			return FALSE;
 	} else {
 		attack = *dflt_attack;
 	}
 
-	return fight( chr1, chr2, &attack, d );
+	return fight( o_p, d_p, &attack, d );
+}
+
+/***************************************************************
+* Ƥ뤫å
+* mbr_t *mbr : С
+* return : Ƥ뤫?
+***************************************************************/
+
+bool_t	chk_fight_zap( mbr_t *mbr )
+{
+	item_t	*eq;
+
+	if( mbr == NULL )
+		return FALSE;
+	if( !is_mbr( mbr ) )
+		return FALSE;
+
+	eq = get_mbr_item_asgn_equip( mbr );
+	if( eq == NULL )
+		return FALSE;
+	if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_NULL )
+		return FALSE;
+	if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_STICK )
+		return FALSE;
+
+	return TRUE;
+}
+
+/***************************************************************
+* ǹ
+* mbr_t *mbr : С
+* return : ?
+***************************************************************/
+
+bool_t	fight_zap( mbr_t *mbr )
+{
+	item_t	*eq;
+
+	if( !is_mbr( mbr ) )
+		return FALSE;
+
+	eq = get_mbr_item_asgn_equip( mbr );
+	if( eq == NULL )
+		return FALSE;
+
+	if( !zap_stick( mbr, &(eq[EQUIP_KIND_BOW]) ) )
+		clr_chr_trgt_act( mbr, FALSE );
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -1698,11 +1736,23 @@ bool_t	fight_x_1(
 		curs_attrset_dflt();
 	}
 
-	if( flg_ninja_crtcl )
+	if( flg_ninja_crtcl ){
 		die_chr( d_p, TRUE, TRUE, TRUE );
-	else
+	} else {
 		add_hp( d_p, -o_dam, TRUE, FALSE );
 
+		/* פ */
+
+		if( is_mbr( o_p ) && (o_dam > 0) ){
+			update_playing_report_making_dam(
+			o_p->ls_mbr_n, attack->resi_kind, o_dam );
+		}
+		if( is_mbr( d_p ) && (o_dam > 0) ){
+			update_playing_report_made_dam(
+			d_p->ls_mbr_n, attack->resi_kind, o_dam );
+		}
+	}
+
 	return TRUE;
 }
 
@@ -1950,6 +2000,17 @@ bool_t	spell_attack(
 	}
 	add_hp( d_p, -dam, TRUE, FALSE );
 
+	/* פ */
+
+	if( is_mbr( o_p ) && (dam > 0) ){
+		update_playing_report_making_dam(
+				o_p->ls_mbr_n, resi, dam );
+	}
+	if( is_mbr( d_p ) && (dam > 0) ){
+		update_playing_report_made_dam(
+				d_p->ls_mbr_n, resi, dam );
+	}
+
 	return TRUE;
 }
 
