@@ -47,6 +47,8 @@ square_dir_t	trans_idx_to_square_dir( long idx );
 long	trans_square_dir_to_idx( square_dir_t dir );
 chr_kind_t	trans_idx_to_chr_kind( long idx );
 long	trans_chr_kind_to_idx( chr_kind_t k );
+position_kind_t	trans_idx_to_position_kind( long idx );
+long	trans_position_kind_to_idx( position_kind_t k );
 main_race_t	trans_idx_to_main_race_kind( long idx );
 long	trans_main_race_kind_to_idx( main_race_t k );
 sub_race_t	trans_idx_to_sub_race_kind( long idx );
@@ -75,6 +77,8 @@ auto_mark_act_t	trans_idx_to_am_act( long idx );
 long	trans_am_act_to_idx( auto_mark_act_t k );
 auto_mark_cond_t	trans_idx_to_am_cond( long idx );
 long	trans_am_cond_to_idx( auto_mark_cond_t k );
+dflt_auto_mark_t	trans_idx_to_am_dflt( long idx );
+long	trans_am_dflt_to_idx( dflt_auto_mark_t k );
 attitude_t	trans_idx_to_attitude_kind( long idx );
 long	trans_attitude_kind_to_idx( attitude_t k );
 item_kind_t	trans_idx_to_item_kind( long idx );
@@ -223,6 +227,7 @@ bool_t	load_game_conf_move_crsr_dflt( char *id, long val );
 bool_t	load_game_conf_music_volume( char *id, long val );
 bool_t	load_game_conf_sound_volume( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
+bool_t	load_game_conf_audio_buf_siz( char *id, long val );
 bool_t	load_game_conf_gnome( char *id, long val );
 bool_t	load_game_conf_set_window_position( char *id, long val );
 bool_t	load_game_conf_win_pos( char *id, long val, win_kind_t kind );
@@ -272,6 +277,7 @@ bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_screen_size( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_audio_buf_siz( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver );
@@ -418,6 +424,7 @@ void	ver_up_game_data_1_1_3( void );
 void	ver_up_game_data_1_2_6( void );
 void	ver_up_game_data_1_2_12( void );
 void	ver_up_game_data_1_2_27( void );
+void	ver_up_game_data_1_2_35( void );
 void	reset_load_game_data( void );
 bool_t	chk_load_game_data( void );
 bool_t	load_game_data_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
