@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.36 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.40 2010/06/03 12:45:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -80,6 +80,31 @@ chr_kind_t	g_chr_trans_tab[] = {
 	/* ɲ */
 };
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
+* 
+* С֤ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* С֤ POSITION_KIND_NULL ǡ롣
+***************************************************************/
+
+position_kind_t	g_position_kind_trans_tab[] = {
+	POSITION_KIND_NULL,
+
+	/*  */
+	POSITION_KIND_FORWARD,
+	/*  */
+	POSITION_KIND_HALFBACK,
+	/*  */
+	POSITION_KIND_BACK,
+
+	/* ɲ */
+};
+
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
@@ -362,10 +387,10 @@ trgt_kind_t	g_trgt_trans_tab[] = {
 * 
 *  Ф˽֤ѹʤͤˡ 
 * 
-* ֹ礤ɬơ֥ɲäơ
+* ܤɬơ֥ɲäơ
 * ֡եΥСѤ롣
 * 
-* ֹ礤 DIST_NEAR ǡ롣
+*  DIST_NEAR ǡ롣
 ***************************************************************/
 
 dist_t	g_dist_trans_tab[] = {
@@ -382,10 +407,10 @@ dist_t	g_dist_trans_tab[] = {
 * 
 *  Ф˽֤ѹʤͤˡ 
 * 
-* ֹ礤ɬơ֥ɲäơ
+* ܤɬơ֥ɲäơ
 * ֡եΥСѤ롣
 * 
-* ֹ礤 AUTO_MARK_TRGT_CLEAR ǡ롣
+*  AUTO_MARK_TRGT_CLEAR ǡ롣
 ***************************************************************/
 
 auto_mark_trgt_t	g_am_trgt_trans_tab[] = {
@@ -406,10 +431,10 @@ auto_mark_trgt_t	g_am_trgt_trans_tab[] = {
 * 
 *  Ф˽֤ѹʤͤˡ 
 * 
-* ֹ礤ɬơ֥ɲäơ
+* ܤɬơ֥ɲäơ
 * ֡եΥСѤ롣
 * 
-* ֹ礤 AUTO_MARK_DIST_NEAR ǡ롣
+*  AUTO_MARK_DIST_NEAR ǡ롣
 ***************************************************************/
 
 auto_mark_dist_t	g_am_dist_trans_tab[] = {
@@ -426,10 +451,10 @@ auto_mark_dist_t	g_am_dist_trans_tab[] = {
 * 
 *  Ф˽֤ѹʤͤˡ 
 * 
-* ֹ礤ɬơ֥ɲäơ
+* ܤɬơ֥ɲäơ
 * ֡եΥСѤ롣
 * 
-* ֹ礤 AUTO_MARK_ACT_FIGHT ǡ롣
+*  AUTO_MARK_ACT_FIGHT ǡ롣
 ***************************************************************/
 
 auto_mark_act_t	g_am_act_trans_tab[] = {
@@ -455,10 +480,10 @@ auto_mark_act_t	g_am_act_trans_tab[] = {
 * 
 *  Ф˽֤ѹʤͤˡ 
 * 
-* ֹ礤ɬơ֥ɲäơ
+* ܤɬơ֥ɲäơ
 * ֡եΥСѤ롣
 * 
-* ֹ礤 AUTO_MARK_COND_NEAREST ǡ롣
+*  AUTO_MARK_COND_NEAREST ǡ롣
 ***************************************************************/
 
 auto_mark_cond_t	g_am_cond_trans_tab[] = {
@@ -495,6 +520,49 @@ auto_mark_cond_t	g_am_cond_trans_tab[] = {
 	/* ɲ */
 };
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
+* 
+* ܤɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+*  DFLT_AUTO_MARK_NULL ǡ롣
+***************************************************************/
+
+dflt_auto_mark_t	g_am_dflt_trans_tab[] = {
+	DFLT_AUTO_MARK_NULL,
+
+	/* Ʈ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT,
+	/* Ʈ() */
+	DFLT_AUTO_MARK_FIGHT_PRIO,
+
+	/* ܶƮ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW,
+	/* ܶƮ() */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
+
+	/* (ɲ) */
+	DFLT_AUTO_MARK_FIGHT_ALL,
+	/* () */
+	DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
+
+	/* ƤΥƥ */
+	DFLT_AUTO_MARK_ITEM_ALL,
+	/* äƤ륢ƥ */
+	DFLT_AUTO_MARK_ITEM_OWN,
+
+	/*  */
+	DFLT_AUTO_MARK_RETREAT,
+	/*  */
+	DFLT_AUTO_MARK_CLEAR,
+
+	/* ɲ */
+};
+
 /***************************************************************
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
@@ -1705,6 +1773,7 @@ spell_kind_t	g_spell_trans_tab[] = {
 	SPELL_KIND_SUMMON_BONE,
 	SPELL_KIND_STORE_LIGHT,
 	SPELL_KIND_DISMISSAL_ELEMENTAL,
+	SPELL_KIND_SHORT_TELEPORT_PARTY,
 };
 
 /***************************************************************
