@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.210 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: gfile.c,v 1.213 2010/05/16 18:52:56 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1138,6 +1138,48 @@ long	trans_chr_kind_to_idx( chr_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥåС֤Ѵ
+* long idx : ǥå
+* return : С
+***************************************************************/
+
+position_kind_t	trans_idx_to_position_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_position_kind_trans_tab )
+			/ sizeof( g_position_kind_trans_tab[0] );
+
+	if( idx < 0 )
+		return POSITION_KIND_FORWARD;
+	if( idx >= max_idx )
+		return POSITION_KIND_FORWARD;
+
+	return( g_position_kind_trans_tab[idx] );
+}
+
+/***************************************************************
+* С֤饤ǥåѴ
+* position_kind_t k : С֤μ
+* return : ǥå
+***************************************************************/
+
+long	trans_position_kind_to_idx( position_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_position_kind_trans_tab )
+			/ sizeof( g_position_kind_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_position_kind_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥåᥤ²Ѵ
 * long idx : ǥå
@@ -1714,6 +1756,48 @@ long	trans_am_cond_to_idx( auto_mark_cond_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥåǥեȤμѴ
+* long idx : ǥå
+* return : ǥեȤμ
+***************************************************************/
+
+dflt_auto_mark_t	trans_idx_to_am_dflt( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_am_dflt_trans_tab )
+			/ sizeof( g_am_dflt_trans_tab[0] );
+
+	if( idx < 0 )
+		return DFLT_AUTO_MARK_NULL;
+	if( idx >= max_idx )
+		return DFLT_AUTO_MARK_NULL;
+
+	return( g_am_dflt_trans_tab[idx] );
+}
+
+/***************************************************************
+* ǥեȤμफ饤ǥåѴ
+* dflt_auto_mark_t k : ǥեȤμ
+* return : ǥå
+***************************************************************/
+
+long	trans_am_dflt_to_idx( dflt_auto_mark_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_am_dflt_trans_tab )
+			/ sizeof( g_am_dflt_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_am_dflt_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ǥåȿѴ
 * long idx : ǥå
