@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.131 2009/06/24 02:44:28 bowkenken Exp $
+* $Id: gmain.c,v 1.143 2010/05/29 14:37:00 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -61,42 +61,47 @@
 ***************************************************************/
 
 static long	flg_term;
+check_memory_def( check_memory_gmain_c_flg_term )
 
 #if	defined( HAVE_TERMIOS_H )
 static struct termios	pre_tbuf;
 #elif	defined( HAVE_TERMIO_H )
 static struct termio	pre_tbuf;
 #endif
+check_memory_def( check_memory_gmain_c_pre_tbuf )
 
 /***************************************************************
 * 
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:md:Vvh"
+#define	STR_OPT	"GCUA:N:P:T:D:S:l:k:e:s:p:m:cd:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
-	{ "gui",           no_argument,       NULL, 'G' },
-	{ "cui",           no_argument,       NULL, 'C' },
-	{ "gui-and-cui",   no_argument,       NULL, 'U' },
-	{ "gnome",         required_argument, NULL, 'N' },
-	{ "set-win-pos",   required_argument, NULL, 'P' },
-	{ "text-mode",     required_argument, NULL, 'T' },
-	{ "sel-graph-dir", required_argument, NULL, 'D' },
-	{ "map-scale",     required_argument, NULL, 'S' },
-	{ "language",      required_argument, NULL, 'l' },
-	{ "clear-key-buf", required_argument, NULL, 'k' },
-	{ "echo-key",      required_argument, NULL, 'e' },
-	{ "use-curses",    required_argument, NULL, 's' },
-	{ "use-keypad",    required_argument, NULL, 'p' },
-	{ "measure-clock", no_argument,       NULL, 'm' },
-	{ "debug",         required_argument, NULL, 'd' },
-	{ "version",       no_argument,       NULL, 'V' },
-	{ "help",          no_argument,       NULL, 'h' },
+	{ "gui",            no_argument,       NULL, 'G' },
+	{ "cui",            no_argument,       NULL, 'C' },
+	{ "gui-and-cui",    no_argument,       NULL, 'U' },
+	{ "audio-buf-size", required_argument, NULL, 'A' },
+	{ "gnome",          required_argument, NULL, 'N' },
+	{ "set-win-pos",    required_argument, NULL, 'P' },
+	{ "text-mode",      required_argument, NULL, 'T' },
+	{ "sel-graph-dir",  required_argument, NULL, 'D' },
+	{ "map-scale",      required_argument, NULL, 'S' },
+	{ "language",       required_argument, NULL, 'l' },
+	{ "clear-key-buf",  required_argument, NULL, 'k' },
+	{ "echo-key",       required_argument, NULL, 'e' },
+	{ "use-curses",     required_argument, NULL, 's' },
+	{ "use-keypad",     required_argument, NULL, 'p' },
+	{ "check-memory",   required_argument, NULL, 'm' },
+	{ "measure-clock",  no_argument,       NULL, 'c' },
+	{ "debug",          required_argument, NULL, 'd' },
+	{ "version",        no_argument,       NULL, 'V' },
+	{ "help",           no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
 };
 #endif	/* HAVE_GETOPT_LONG */
+check_memory_def( check_memory_gmain_c_long_opt )
 
 /***************************************************************
 * 
@@ -105,41 +110,45 @@ static struct option	long_opt[] = {
 char	str_usage[] = {
 	"Usage: %s [OPTION]...\n"
 	"OPTION:\n"
-	"  -G, --gui                set GUI mode\n"
-	"  -C, --cui                set CUI mode\n"
-	"  -U, --gui-and-cui        set GUI and CUI mode\n"
-	"  -N, --gnome              window manager is GNOME\n"
-	"                             ON or OFF\n"
-	"  -P, --set-win-pos        set window position\n"
-	"                             ON or OFF\n"
+	"  -G, --gui                 set GUI mode\n"
+	"  -C, --cui                 set CUI mode\n"
+	"  -U, --gui-and-cui         set GUI and CUI mode\n"
+	"  -A, --audio-buf-size=SIZE set audio buffer size\n"
+	"  -N, --gnome               window manager is GNOME\n"
+	"                              ON or OFF\n"
+	"  -P, --set-win-pos         set window position\n"
+	"                              ON or OFF\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -T, --text-mode=POINT    set TEXT mode:\n"
-	"                             point of font, ON or OFF\n"
-	"  -D, --sel-graph-dir=DIR  select graphic directory:\n"
-	"                             graphic directory\n"
-	"  -S, --map-scale=N        set scale of map character:\n"
-	"                             scale(%%)\n"
+	"  -T, --text-mode=POINT     set TEXT mode:\n"
+	"                              point of font, ON or OFF\n"
+	"  -D, --sel-graph-dir=DIR   select graphic directory:\n"
+	"                              graphic directory\n"
+	"  -S, --map-scale=N         set scale of map character:\n"
+	"                              scale(%%)\n"
 #endif
-	"  -l, --language=LANGUAGE  set language:\n"
-	"                             language\n"
+	"  -l, --language=LANGUAGE   set language:\n"
+	"                              language\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
-	"                             ON or OFF\n"
+	"  -k, --clear-key-buf=FLAG  clear key buffer:\n"
+	"                              ON or OFF\n"
 #endif
-	"  -e, --echo-key=FLAG      echo key:\n"
-	"                             ON or OFF\n"
-	"  -s, --use-curses=FLAG    use curses library:\n"
-	"                             ON or OFF\n"
-	"  -p, --use-keypad=FLAG    use cursor key (call keypad):\n"
-	"                             ON or OFF\n"
-	"  -m, --measure-clock      measure frame rate\n"
+	"  -e, --echo-key=FLAG       echo key:\n"
+	"                              ON or OFF\n"
+	"  -s, --use-curses=FLAG     use curses library:\n"
+	"                              ON or OFF\n"
+	"  -p, --use-keypad=FLAG     use cursor key (call keypad):\n"
+	"                              ON or OFF\n"
+	"  -m, --check-memory=FLAG   check memory:\n"
+	"                              ON or OFF\n"
+	"  -c, --measure-clock       measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -d, --debug=FLAG         set debug mode:\n"
-	"                             ON or OFF\n"
+	"  -d, --debug=FLAG          set debug mode:\n"
+	"                              ON or OFF\n"
 #endif
-	"  -V, -v, --version        display version and exit\n"
-	"  -h, --help               display this help and exit\n"
+	"  -V, -v, --version         display version and exit\n"
+	"  -h, --help                display this help and exit\n"
 };
+check_memory_def( check_memory_gmain_c_str_usage )
 
 /***************************************************************
 * Τν
@@ -344,6 +353,16 @@ void	ending( void )
 			case CASE_EXIT:
 				exit_game( EXIT_SUCCESS );
 				break;
+			case 'S':
+				set_flg_skip_scene_ending( TRUE );
+				call_demo_ending_skip_scene();
+				break;
+			case CASE_CRSR_UP:
+				add_z_speed_space( +1 );
+				break;
+			case CASE_CRSR_DOWN:
+				add_z_speed_space( -1 );
+				break;
 			}
 		}
 	}
@@ -366,10 +385,14 @@ void	init_arg( void )
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
 
+	g_audio_buf_siz_arg_overwrite = FALSE;
+	g_audio_buf_siz_arg = 1024;
+	g_audio_buf_siz = 1024;
+
 	g_flg_win_pos_arg_overwrite = FALSE;
 	g_flg_gnome_arg = TRUE;
-	g_flg_set_win_pos_arg = TRUE;
 	g_flg_gnome = TRUE;
+	g_flg_set_win_pos_arg = TRUE;
 	g_flg_set_win_pos = TRUE;
 
 	g_flg_text_mode = FALSE;
@@ -388,9 +411,10 @@ void	init_arg( void )
 	g_flg_echo_key = FALSE;
 
 	g_flg_use_curs = TRUE;
-	g_flg_use_keypad = FALSE;
+	g_flg_use_keypad = TRUE;
 
 	g_flg_measure_clk_tck = FALSE;
+	g_flg_check_memory = TRUE;
 
 	g_flg_send_item_exec_turn = FALSE;
 }
@@ -451,6 +475,10 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
+		case 'A':
+			g_audio_buf_siz_arg_overwrite = TRUE;
+			chk_opt_num( optarg, &g_audio_buf_siz_arg, TRUE );
+			break;
 		case 'N':
 			g_flg_win_pos_arg_overwrite = TRUE;
 			chk_opt_flg( optarg, &g_flg_gnome_arg, TRUE );
@@ -499,6 +527,9 @@ void	chk_arg( int argc, char **argv )
 			chk_opt_flg( optarg, &g_flg_use_keypad, TRUE );
 			break;
 		case 'm':
+			chk_opt_flg( optarg, &g_flg_check_memory, TRUE );
+			break;
+		case 'c':
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
@@ -646,6 +677,10 @@ void	overwrite_arg()
 		g_flg_gnome = g_flg_gnome_arg;
 		g_flg_set_win_pos = g_flg_set_win_pos_arg;
 	}
+
+	if( g_audio_buf_siz_arg_overwrite ){
+		g_audio_buf_siz = g_audio_buf_siz_arg;
+	}
 }
 
 /***************************************************************
@@ -680,9 +715,10 @@ void	close_game( long code )
 {
 	close_item();
 
-	curs_move( get_max_line() - 1, SCREEN_MIN_X );
-	reset_scrn();
+	if( !g_flg_use_curs )
+		curs_move( get_screen_row() - 1, SCREEN_MIN_X );
 
+	reset_scrn();
 	fflush( stdout );
 	fflush( stderr );
 
@@ -721,7 +757,7 @@ void	about_game( bool_t flg_init )
 		return;
 	}
 
-	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
+	curs_move( get_map_row() + 1, SCREEN_MIN_X );
 
 	dis_scrn();
 
@@ -1125,6 +1161,7 @@ void	set_key_wait_vtime( long wait_vtime )
 # endif
 
 	/* Խ */
+	tbuf.c_cc[VMIN] = 0;
 	tbuf.c_cc[VTIME] = wait_vtime;
 
 	/* Υå */
@@ -1202,3 +1239,104 @@ void	clr_key_wait_dos( void )
 {
 	set_key_wait_vtime( 0 );
 }
+
+/***************************************************************
+* ꡼å
+* check_memory_t mem : å꡼
+* const char *msg : 顼å
+***************************************************************/
+
+bool_t	check_memory( check_memory_t mem, const char *msg )
+{
+	long	i;
+
+	if( mem == NULL )
+		return FALSE;
+	if( msg == NULL )
+		msg = "";
+
+	for( i = 0; i < CHECK_MEMORY_MAX_LEN / 2; i++ ){
+		if( (mem[i * 2 + 0] == 0xbe) && (mem[i * 2 + 1] == 0xef) )
+			continue;
+
+		print_msg( FLG_MSG_ERR,
+				"memory error: %s: [0x%2lx,0x%2lx]",
+				msg, mem[i * 2 + 0], mem[i * 2 + 1] );
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/***************************************************************
+* ƤΥ꡼å
+***************************************************************/
+
+void	check_memory_all( void )
+{
+	check_memory_amenu_c();
+	check_memory_chr_c();
+	check_memory_curs_c();
+	check_memory_draw_c();
+	check_memory_dun_c();
+	check_memory_ending_ep_c();
+	check_memory_ending_space_c();
+	check_memory_fight_c();
+	check_memory_fx_c();
+	check_memory_gf_conf_c();
+	check_memory_gf_crsr_c();
+	check_memory_gf_gconf_c();
+	check_memory_gf_outmap_c();
+	check_memory_gf_replay_c();
+	check_memory_gf_save_c();
+	check_memory_gf_town_c();
+	check_memory_gfile_c();
+	check_memory_gmain_c();
+	check_memory_imenu_c();
+	check_memory_item_c();
+	check_memory_key_item_c();
+	check_memory_last_boss_c();
+#if	defined( D_GTK )
+#elif	defined( D_MFC )
+#elif	defined( D_DOS )
+	check_memory_main_dos_c();
+#else
+	check_memory_main_unix_c();
+#endif
+	check_memory_map_event_c();
+	check_memory_menu_c();
+	check_memory_misc_c();
+	check_memory_mmenu_c();
+	check_memory_mnstr_act_c();
+	check_memory_mnstr_c();
+	check_memory_msg_c();
+	check_memory_nest_flg_c();
+	check_memory_party_c();
+	check_memory_pet_c();
+	check_memory_play_rep_c();
+	check_memory_replay_c();
+	check_memory_request_c();
+	check_memory_scene_c();
+	check_memory_skill_c();
+	check_memory_spell_c();
+	check_memory_tmenu_c();
+	check_memory_town_c();
+	check_memory_trap_c();
+	check_memory_turn_c();
+}
+
+/***************************************************************
+* gmain.c Υ꡼å
+***************************************************************/
+
+void	check_memory_gmain_c( void )
+{
+	check_memory( check_memory_gmain_c_flg_term,
+			"gmain.c: flg_term" );
+	check_memory( check_memory_gmain_c_pre_tbuf,
+			"gmain.c: pre_tbuf" );
+	check_memory( check_memory_gmain_c_long_opt,
+			"gmain.c: long_opt" );
+	check_memory( check_memory_gmain_c_str_usage,
+			"gmain.c: str_usage" );
+}
