@@ -60,6 +60,9 @@ char	*menu_mbr_give_gold( mbr_t *mbr_from );
 char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
 void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
 char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
+char	*cb_menu_position( menu_t **pp, menu_t **dflt );
+char	*exec_menu_position( mbr_t *mbr );
+char	*cb_menu_position_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_move_abs( menu_t **pp, menu_t **dflt );
@@ -158,6 +161,10 @@ char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
 void	set_color_attr( curs_attr_t *attr, bool_t flg_on, chtype_t ch );
 char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_demo( menu_t **pp, menu_t **dflt );
+char	*cb_menu_skip_cut_in( menu_t **pp, menu_t **dflt );
+char	*cb_menu_star_cui( menu_t **pp, menu_t **dflt );
+char	*cb_menu_star_gui( menu_t **pp, menu_t **dflt );
 char	*cb_menu_key_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_clr_key_buf_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_clr_key_buf_every( menu_t **pp, menu_t **dflt );
@@ -171,10 +178,21 @@ char	*cb_menu_mouse( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
+char	*cb_menu_func_unset( menu_t **pp, menu_t **dflt );
 long	get_func_draw_n( long n );
 char	*cb_menu_gui( menu_t **pp, menu_t **dflt );
 char	*cb_menu_move_crsr_dflt( menu_t **pp, menu_t **dflt );
+char	*cb_menu_audio( menu_t **pp, menu_t **dflt );
+char	*cb_menu_music_volume( menu_t **pp, menu_t **dflt );
+char	*cb_menu_sound_volume( menu_t **pp, menu_t **dflt );
+rate_t	get_music_volume_rate( void );
+rate_t	set_music_volume_rate( rate_t rate );
+rate_t	get_sound_volume_rate( void );
+rate_t	set_sound_volume_rate( rate_t rate );
+char	*cb_menu_mute_audio( menu_t **pp, menu_t **dflt );
+void	mute_audio( bool_t flg );
 char	*cb_menu_replay_music( menu_t **pp, menu_t **dflt );
+char	*cb_menu_set_audio_buf_siz( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_kind_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_macro_init( menu_t **pp, menu_t **dflt );
