@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.h,v 1.19 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: misc.h,v 1.22 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MISC_H
@@ -40,6 +40,9 @@
 /* Ϥκ */
 #define	FIGURE_MAX_N	10
 
+/* ѥ */
+#define	DBL_PI	3.14159265358979323846
+
 /***************************************************************
 * ޥå׾δʸ
 ***************************************************************/
