@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.56 2009/07/12 08:35:36 bowkenken Exp $
+* $Id: mmenu.c,v 1.60 2010/05/15 19:34:47 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -33,6 +33,9 @@
 
 /**/
 
+/* ذưʤɤǥ˥塼ꥻåȤ뤫? */
+#define	FLG_RESET_MENU	0
+
 #define	LS_CLASS_N_PER_PAGE	16
 
 /**/
@@ -127,7 +130,9 @@ void	init_main_menu( void )
 
 void	reset_static_main_menu( void )
 {
+#if	FLG_RESET_MENU
 	g_menu_dflt_main = NULL;
+#endif
 
 	/**/
 
@@ -1667,6 +1672,9 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 	clr_flg_menu( *pp, "alias", FLG_MENU_HIDDEN );
 	clr_flg_menu( *pp, "check", FLG_MENU_HIDDEN );
 
+	if( chk_have_chest( pty->mbr[g_sel_mbr_n] ) )
+		clr_flg_menu( *pp, "put in chest", FLG_MENU_HIDDEN );
+
 	switch( g_sel_item->kind ){
 	case ITEM_KIND_NULL:
 	case ITEM_KIND_MAX_N:
@@ -1697,6 +1705,8 @@ char	*cb_menu_item_sel_init( menu_t **pp, menu_t **dflt )
 		clr_flg_menu( *pp, "eat", FLG_MENU_HIDDEN );
 		break;
 	case ITEM_KIND_CHEST:
+		set_flg_menu( *pp, "put in chest", FLG_MENU_HIDDEN );
+		clr_flg_menu( *pp, "list chest", FLG_MENU_HIDDEN );
 		break;
 	case ITEM_KIND_TOBACCO:
 		clr_flg_menu( *pp, "smoke", FLG_MENU_HIDDEN );
@@ -1999,6 +2009,208 @@ char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_item_put_in_chest( menu_t **pp, menu_t **dflt )
+{
+	long	n;
+	char	*res;
+	party_t	*pty = get_party();
+	mbr_t	*mbr;
+	item_t	*tmp;
+
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	mbr = pty->mbr[g_sel_mbr_n];
+
+	if( g_sel_item == NULL )
+		return STR_MENU_ERR;
+
+	n = g_sel_item->n;
+	res = exec_menu_sel_num( &n, 1, g_sel_item->n );
+	if( res != NULL )
+		return res;
+
+	tmp = alloc_item();
+	if( tmp == NULL )
+		return STR_MENU_ERR;
+
+	copy_item( tmp, g_sel_item );
+	inc_item( tmp, -(tmp->n - n) );
+
+	if( !put_item_in_chest_quick( mbr, tmp ) ){
+		del_item( tmp );
+		return STR_MENU_CANCEL;
+	}
+
+	inc_item( g_sel_item, -n );
+
+	return "/item";
+}
+
+/**/
+
+char	*cb_menu_item_ls_chest( menu_t **pp, menu_t **dflt )
+{
+	party_t	*pty = get_party();
+	menu_t	*ls;
+	mbr_t	*mbr;
+	item_t	*chest, *head, *p;
+	long	j, k;
+
+	if( g_sel_item == NULL )
+		return STR_MENU_ERR;
+	if( g_sel_item->kind != ITEM_KIND_CHEST )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
+		return STR_MENU_ERR;
+
+	mbr = pty->mbr[g_sel_mbr_n];
+	chest = g_sel_item;
+
+	if( chest->dat.chest.trap != NULL ){
+		curs_attrset_chr( mbr, -1, FALSE );
+		print_msg( FLG_NULL, MSG_ERR_MENU_LS_CHEST_TRAP,
+				chest->name );
+		curs_attrset_dflt();
+
+		return STR_MENU_CANCEL;
+	}
+
+	if( chk_flg_or( mbr->stat,
+			FLG_STAT_NOT_EXIST
+			| FLG_STAT_DEAD
+			| FLG_STAT_STONE
+			| FLG_STAT_PARALYZE
+			| FLG_STAT_SLEEP
+			| FLG_STAT_FAINT ) ){
+		print_msg( FLG_NULL, MSG_ERR_MENU_SEL_ITEM, mbr->name );
+		return STR_MENU_CANCEL;
+	}
+
+	ls = ls_menu_chest;
+	k = 0;
+
+	str_nz_cpy( ls[k].path, "/chest", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	ls[k].msg[0] = '\0';
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	str_nz_cpy( ls[k].path, "/chest/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
+	ls[k].accel_key = '\0';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_ITEM_LS_CHEST, MENU_MSG_MAX_BYTE );
+	ls[k].call_back = NULL;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
+	head = chest->dat.chest.contents;
+	p = head->next;
+	for( j = 0; j < CHEST_HOLD_MAX_N; j++, p = p->next ){
+		if( p == head )
+			break;
+
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/chest/%ld", j );
+		str_nz_cpy( ls[k].kind, "<OpenWinItem>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = (char)('A' + j);
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_NULL;
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, "%s", p->name );
+		ls[k].call_back = cb_menu_chest_sel;
+		ls[k].arg = (void *)p;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
+
+	if( j <= 0 ){
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/chest/%ld", j );
+		str_nz_cpy( ls[k].kind, "<Item>",
+				MENU_KIND_MAX_LEN );
+		ls[k].accel_key = (char)('A' + j);
+		ls[k].short_key[0] = '\0';
+		ls[k].n_msg = N_MSG_ITEM_NO_SEL;
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE, MSG_ITEM_NO_SEL );
+		ls[k].call_back = cb_menu_chest_sel;
+		ls[k].arg = NULL;
+		ls[k].flg = FLG_NULL;
+		k++;
+	}
+
+	ls[k].path[0] = '\0';
+
+	while( 1 ){
+		char	*res;
+
+		res = exec_menu( ls, NULL, NULL );
+		if( res == NULL )
+			continue;
+		if( strcmp( res, STR_MENU_CANCEL ) == 0 )
+			return "/item";
+
+		return res;
+	}
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_chest_sel( menu_t **pp, menu_t **dflt )
+{
+	party_t	*pty = get_party();
+	mbr_t	*mbr;
+	item_t	*item, *tmp;
+	long	n;
+	char	*res;
+
+	if( g_sel_mbr_n <= -1 )
+		return STR_MENU_ERR;
+	if( g_sel_mbr_n >= MBR_MAX_N )
+		return STR_MENU_ERR;
+
+	mbr = pty->mbr[g_sel_mbr_n];
+	item = (item_t *)((*pp)->arg);
+	if( mbr == NULL )
+		return STR_MENU_ERR;
+	if( item == NULL )
+		return STR_MENU_CANCEL;
+
+	n = item->n;
+	res = exec_menu_sel_num( &n, 1, item->n );
+	if( res != NULL )
+		return res;
+
+	tmp = alloc_item();
+	if( tmp == NULL )
+		return STR_MENU_ERR;
+
+	copy_item( tmp, item );
+	inc_item( tmp, -(tmp->n - n) );
+
+	if( !give_mbr_item( mbr, tmp, FALSE ) ){
+		del_item( tmp );
+		return STR_MENU_CANCEL;
+	}
+
+	inc_item( item, -n );
+
+	return "/item sel/list chest";
+}
+
+/**/
+
 char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt )
 {
 	long	n;
