@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.47 2009/07/25 20:47:15 bowkenken Exp $
+* $Id: msg.c,v 1.51 2010/01/12 05:08:18 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -251,11 +251,15 @@ void	init_msg( void )
 	/* Ķѿθͤ */
 
 	if( g_language == NULL ){
+		lang = NULL;
+#ifdef	HAVE_GETENV
 		lang = getenv( STR_ENV_LANG );
+#endif
 		if( lang == NULL )
 			lang = STR_DFLT_LANG;
 #ifdef	D_GTK
-		lang = STR_DFLT_LANG;
+		if( strcmp( lang, "ja_JP.eucJP" ) == 0 )
+			lang = "ja_JP.UTF-8";
 #endif
 	} else {
 		lang = g_language;
