@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.116 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: request.c,v 1.118 2010/05/13 13:47:13 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1975,6 +1975,9 @@ void	chk_find_request_chr( chr_t *chr )
 	case REQUEST_KIND_EXTERMINATE:
 		break;
 	case REQUEST_KIND_REVENGE:
+		if( !chk_watch_request_client( req ) )
+			break;
+
 		msg_fema = MSG_WORDS_REQUEST_REVENGE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_REVENGE_FIND_MALE;
 
@@ -2206,6 +2209,12 @@ void	chk_finish_request_exterminate(
 			continue;
 		if( g_request[i].mnstr_kind != mnstr_kind )
 			continue;
+		if( (req_kind == REQUEST_KIND_TOUR_GUIDE)
+				|| (req_kind == REQUEST_KIND_REVENGE) ){
+			if( !chk_watch_request_client( &(g_request[i]) ) ){
+				continue;
+			}
+		}
 
 		req = &(g_request[i]);
 		req->mnstr_exterminate_n += add;
@@ -2241,6 +2250,11 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 	if( cmp_chr( npc, chr ) )
 		return FALSE;
 
+	if( !chk_watch_request_client( req ) ){
+		free_request( req );
+		return FALSE;
+	}
+
 	print_words_win( npc->name, npc->sex.cur,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_MALE );
@@ -2416,6 +2430,43 @@ bool_t	give_party_reward_item( item_t *item )
 	return give_party_item( item, TRUE, TRUE );
 }
 
+/***************************************************************
+* 礬ɸݤΤ򸫤Ƥ뤫?
+* request_t *req : 
+* return : Ƥ뤫?
+***************************************************************/
+
+bool_t	chk_watch_request_client( request_t *req )
+{
+	long	i;
+	pet_t	*npc;
+	pet_t	**party_npc = get_party_pet();
+
+	if( req == NULL )
+		return FALSE;
+	if( (req->kind != REQUEST_KIND_TOUR_GUIDE)
+			&& (req->kind != REQUEST_KIND_REVENGE) ){
+		return FALSE;
+	}
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		npc = party_npc[i];
+
+		if( npc == NULL )
+			continue;
+		if( chk_flg_or( npc->stat,
+				(FLG_STAT_NOT_EXIST | FLG_STAT_DEAD) ) ){
+			continue;
+		}
+		if( npc->work.request != req )
+			continue;
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 /***************************************************************
 * طƤΰ̤
 * request_t *req : 
@@ -2670,6 +2721,24 @@ void	put_request_mnstr( void )
 	}
 }
 
+/***************************************************************
+* 饯 طΥڥå(NPC)?
+* chr_t *chr : ˥塼ꥹ
+* return : ڥå(NPC)?
+***************************************************************/
+
+bool_t	is_client( chr_t *chr )
+{
+	if( chr == NULL )
+		return FALSE;
+	if( !is_pet( chr ) )
+		return FALSE;
+	if( chr->work.request == NULL )
+		return FALSE;
+
+	return TRUE;
+}
+
 /***************************************************************
 * ѡƥƤꥹȤΥ˥塼
 * menu_t **pp : ˥塼ꥹ
