@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.212 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: spell.c,v 1.218 2010/05/29 14:37:00 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -33,6 +33,9 @@
 
 /**/
 
+/* ذưʤɤǥ˥塼ꥻåȤ뤫? */
+#define	FLG_RESET_MENU	0
+
 /* ξǵʳȤɤ? */
 #define	FLG_SPELL_SANCTUARY	TRUE
 
@@ -68,6 +71,7 @@ static cast_tab_t	cast_tab[LS_MBR_MAX_N][SPELL_KIND_MAX_N];
 check_memory_def( check_memory_spell_c_cast_tab )
 
 static mbr_t	*g_sel_mbr;
+static mbr_t	*g_pre_sel_mbr;
 static spell_tab_t	*g_sel_spell;
 check_memory_def( check_memory_spell_c_g_sel_mbr )
 
@@ -96,18 +100,17 @@ check_memory_def( check_memory_spell_c_g_reg_spell )
 
 /**/
 
-static mbr_t	*static_cb_menu_sel_spell__pre_sel_mbr;
-
-/**/
-
 void	init_spell( void )
 {
 	long	m;
 	long	k;
 	menu_t	*ls;
-	long	max_len, min_len;
+	long	max_len;
+	int	min_len;
 	long	i;
 
+	g_pre_sel_mbr = NULL;
+
 	for( m = 0; m < LS_MBR_MAX_N; m++ )
 		init_spell_new_mbr( m );
 
@@ -136,6 +139,8 @@ void	init_spell( void )
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		if( ls[i].path[0] == '\0' )
 			break;
+		if( ls[i].arg == NULL )
+			continue;
 
 		max_len = max_l( max_len, str_len_draw(
 				MSG( ls[i].n_msg ) ) );
@@ -176,30 +181,31 @@ void	init_spell( void )
 
 void	reset_static_spell( void )
 {
-	long	m;
-
 	/* cast_tab */
 
+#if	FLG_RESET_MENU
 	g_sel_mbr = NULL;
+	g_pre_sel_mbr = NULL;
 	g_sel_spell = NULL;
 
-	for( m = 0; m < LS_MBR_MAX_N; m++ ){
-		long	k;
+	{
+		long	m;
 
-		g_dflt_spell_abl[m] = NULL;
-		for( k = 0; k < ABL_KIND_MAX_N; k++ ){
-			g_dflt_spell[m][k] = NULL;
-			g_dflt_spell_extent[m][k] = NULL;
+		for( m = 0; m < LS_MBR_MAX_N; m++ ){
+			long	k;
+
+			g_dflt_spell_abl[m] = NULL;
+			for( k = 0; k < ABL_KIND_MAX_N; k++ ){
+				g_dflt_spell[m][k] = NULL;
+				g_dflt_spell_extent[m][k] = NULL;
+			}
 		}
 	}
 	g_sel_spell_abl = ABL_KIND_HP;
+#endif
 
-	g_vfx_n = 0;
+	/* g_vfx_n = 0; */
 	/* g_vfx_bgn, g_vfx_end */;
-
-	/**/
-
-	static_cb_menu_sel_spell__pre_sel_mbr = NULL;
 }
 
 /**/
@@ -312,13 +318,10 @@ void	reset_spell( void )
 
 char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 {
-	mbr_t	*pre_sel_mbr;
 	pos_t	*crsr;
 	bool_t	flg_sel_mbr;
 	char	*str_goto;
 
-	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
-
 	set_menu_dflt_main( *pp );
 
 	crsr = get_crsr();
@@ -332,7 +335,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		if( flg_sel_mbr ){
 			char	*str;
 
-			g_sel_mbr = pre_sel_mbr;
+			g_sel_mbr = g_pre_sel_mbr;
 
 			str = exec_menu_sel_mbr( &g_sel_mbr, NULL,
 					FALSE, FALSE );
@@ -342,8 +345,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		if( g_sel_mbr == NULL )
 			return STR_MENU_ERR;
 
-		pre_sel_mbr = g_sel_mbr;
-		static_cb_menu_sel_spell__pre_sel_mbr = pre_sel_mbr;
+		g_pre_sel_mbr = g_sel_mbr;
 
 		str_goto = menu_sel_spell( g_sel_mbr );
 		if( str_goto == NULL )
@@ -1133,6 +1135,20 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	fx_cast_spell( chr, tab );
 
 	set_vfx_attr( &prev_attr );
+
+	/* פ */
+
+	if( is_mbr( chr ) ){
+		update_playing_report_using_spell(
+				chr->ls_mbr_n, tab->kind );
+	}
+	if( chr->trgt.kind == TRGT_KIND_MBR){
+		mbr_t	*mbr;
+
+		mbr = (mbr_t *)(chr->trgt.p);
+		update_playing_report_used_spell(
+				mbr->ls_mbr_n, tab->kind );
+	}
 }
 
 /**/
@@ -1871,8 +1887,10 @@ void	chr_cast_spell_sub(
 
 	/* ɸ˻̤äƤ뤫å */
 
-	if( !flg_chr || (trgt_kind == TRGT_KIND_MNSTR_NULL)
-			||  (trgt_kind != TRGT_KIND_POS) ){
+	if( trgt_kind == TRGT_KIND_DOOR ){
+		;/**/
+	} else if( !flg_chr || (trgt_kind == TRGT_KIND_MNSTR_NULL)
+			||  (trgt_kind == TRGT_KIND_POS) ){
 		pos_t	pos1, pos2;
 
 		pos1.x = chr->x;
@@ -1996,6 +2014,9 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_STORE_LIGHT:
 		fx_store_light( chr );
 		break;
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
+		fx_short_teleport_party( chr->x, chr->y );
+		break;
 	case SPELL_KIND_TELEPORT_PARTY:
 		fx_teleport_party_charge();
 		break;
@@ -2388,7 +2409,7 @@ void	chr_cast_spell_sub(
 		fx_dispel_undead( chr, trgt_kind, (chr_t *)p, rate );
 		break;
 	case SPELL_KIND_ESCAPE:
-		fx_teleport_party_charge();
+		fx_escape( chr->x, chr->y );
 		break;
 	case SPELL_KIND_SANCTUARY:
 		fx_sanctuary( chr, ABL_KIND_PRI );
@@ -2708,6 +2729,7 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
 	case SPELL_KIND_STORE_LIGHT:
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
@@ -3618,6 +3640,7 @@ char	*get_spell_vfx_str( spell_kind_t spell_kind )
 	case SPELL_KIND_LIGHT:
 	case SPELL_KIND_DARKNESS:
 	case SPELL_KIND_STORE_LIGHT:
+	case SPELL_KIND_SHORT_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT_PARTY:
 	case SPELL_KIND_TELEPORT:
 	case SPELL_KIND_RECALL:
