@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: win-kind.h,v 1.1 2008/05/02 04:32:50 bowkenken Exp $
+* $Id: win-kind.h,v 1.8 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef WIN_KIND_H
@@ -46,6 +46,11 @@ typedef enum {
 	WIN_KIND_STAT_6,
 	WIN_KIND_INPUT_NUM,
 	WIN_KIND_INPUT_STRING,
+	WIN_KIND_WORDS,
+	WIN_KIND_REPLAY,
+	WIN_KIND_CLASS_EDIT,
+	WIN_KIND_SKILL_EDIT,
+	WIN_KIND_CHR_SHEET,
 	WIN_KIND_MAX_N,
 } win_kind_t;
 
